@@ -1,26 +1,25 @@
-library(testthat)
-library(recipes)
-library(dplyr)
-library(modeldata)
-
 test_that("errors if there isn't enough data", {
-  data("credit_data")
+  skip_if_not_installed("modeldata")
+
+  data("credit_data", package = "modeldata")
   credit_data0 <- credit_data
 
   credit_data0$Status <- as.character(credit_data0$Status)
   credit_data0$Status[1] <- "dummy"
   credit_data0$Status <- as.factor(credit_data0$Status)
 
-  expect_error(
+  expect_snapshot(
+    error = TRUE,
     recipe(Status ~ Age, data = credit_data0) %>%
       step_smotenc(Status) %>%
-      prep(),
-    "Not enough observations"
+      prep()
   )
 })
 
 test_that("basic usage", {
-  data(ames)
+  skip_if_not_installed("modeldata")
+
+  data("ames", package = "modeldata")
 
   rec1 <- recipe(Alley ~ MS_SubClass + MS_Zoning + Lot_Frontage + Lot_Area + Street,
                  data = ames) %>%
@@ -33,44 +32,24 @@ test_that("basic usage", {
 
   expect_equal(sort(te_xtab), sort(og_xtab))
 
-  expect_warning(prep(rec1), NA)
-})
-
-test_that("bake method errors when needed non-standard role columns are missing", {
-  rec <- recipe(class ~ x + y, data = circle_example) %>%
-    step_smotenc(class, skip = FALSE) %>%
-    add_role(class, new_role = "potato") %>%
-    update_role_requirements(role = "potato", bake = FALSE)
-
-  trained <- prep(rec, training = circle_example, verbose = FALSE)
-
-  expect_error(bake(trained, new_data = circle_example[, -3]),
-               class = "new_data_missing_column")
-})
-
-test_that("printing", {
-  rec <- recipe(class ~ x + y, data = circle_example) %>%
-    step_smotenc(class)
-  expect_snapshot(print(rec))
-  expect_snapshot(prep(rec))
+  expect_no_warning(prep(rec1))
 })
 
 test_that("bad data", {
-
   rec <- recipe(~., data = circle_example)
   # numeric check
-  expect_error(
+  expect_snapshot(
+    error = TRUE,
     rec %>%
       step_smotenc(x) %>%
-      prep(),
-    regexp = "should be a factor variable."
+      prep()
   )
   # Multiple variable check
-  expect_error(
+  expect_snapshot(
+    error = TRUE,
     rec %>%
       step_smotenc(class, id) %>%
-      prep(),
-    regexp = "The selector should select at most a single variable"
+      prep()
   )
 })
 
@@ -81,22 +60,23 @@ test_that("allows for character variables", {
     stringsAsFactors = FALSE
   )
 
-  expect_error(
+  expect_no_error(
     recipe(~., data = df_char) %>%
       step_smotenc(x) %>%
-      prep(),
-    NA
+      prep()
   )
 })
 
 test_that("NA in response", {
-  data(credit_data)
+  skip_if_not_installed("modeldata")
 
-  expect_error(
+  data("credit_data", package = "modeldata")
+
+  expect_snapshot(
+    error = TRUE,
     recipe(Job ~ Age, data = credit_data) %>%
       step_smotenc(Job) %>%
-      prep(),
-    regexp = "NAs found ind: Job."
+      prep()
   )
 })
 
@@ -138,6 +118,10 @@ test_that("test tidy()", {
 })
 
 test_that("ratio value works when oversampling", {
+  skip_if_not_installed("modeldata")
+
+  data("ames", package = "modeldata")
+
   res1 <- recipe(Alley ~ MS_SubClass + MS_Zoning + Lot_Frontage + Lot_Area + Street,
                  data = ames) %>%
     step_smotenc(Alley) %>%
@@ -158,17 +142,20 @@ test_that("ratio value works when oversampling", {
 })
 
 test_that("allows multi-class", {
-  data("credit_data")
-  expect_error(
+  skip_if_not_installed("modeldata")
+
+  data("credit_data", package = "modeldata")
+  expect_no_error(
     recipe(Home ~ Age + Income + Assets, data = credit_data) %>%
       step_impute_mean(Income, Assets) %>%
-      step_smotenc(Home),
-    NA
+      step_smotenc(Home)
   )
 })
 
 test_that("majority classes are ignored if there is more than 1", {
-  data("penguins")
+  skip_if_not_installed("modeldata")
+  
+  data("penguins", package = "modeldata")
   rec1_p2 <- recipe(species ~ bill_length_mm + bill_depth_mm,
                     data = penguins[-(1:28), ]) %>%
     step_impute_mean(all_predictors()) %>%
@@ -249,48 +236,6 @@ test_that("id variables don't turn predictors to factors", {
   expect_equal(is.double(rec_id$y), TRUE)
 })
 
-
-test_that("empty selection prep/bake is a no-op", {
-  rec1 <- recipe(mpg ~ ., mtcars)
-  rec2 <- step_smotenc(rec1)
-
-  rec1 <- prep(rec1, mtcars)
-  rec2 <- prep(rec2, mtcars)
-
-  baked1 <- bake(rec1, mtcars)
-  baked2 <- bake(rec2, mtcars)
-
-  expect_identical(baked1, baked1)
-})
-
-test_that("empty selection tidy method works", {
-  rec <- recipe(mpg ~ ., mtcars)
-  rec <- step_smotenc(rec)
-
-  expect_identical(
-    tidy(rec, number = 1),
-    tibble(terms = character(), id = character())
-  )
-
-  rec <- prep(rec, mtcars)
-
-  expect_identical(
-    tidy(rec, number = 1),
-    tibble(terms = character(), id = character())
-  )
-})
-
-test_that("empty printing", {
-  rec <- recipe(mpg ~ ., mtcars)
-  rec <- step_smotenc(rec)
-
-  expect_snapshot(rec)
-
-  rec <- prep(rec, mtcars)
-
-  expect_snapshot(rec)
-})
-
 test_that("Doesn't error if no upsampling is done (#119)", {
   dat <- data.frame(
     outcome = c(rep("X", 101), rep("Z", 50)),
@@ -316,7 +261,89 @@ test_that("tunable", {
   )
 })
 
-test_that("tunable is setup to works with extract_parameter_set_dials works", {
+test_that("bad args", {
+  expect_snapshot(
+    error = TRUE,
+    recipe(~., data = mtcars) %>%
+      step_smotenc(over_ratio = "yes") %>%
+      prep()
+  )
+  expect_snapshot(
+    error = TRUE,
+    recipe(~., data = mtcars) %>%
+      step_smotenc(neighbors = TRUE) %>%
+      prep()
+  )
+  expect_snapshot(
+    error = TRUE,
+    recipe(~., data = mtcars) %>%
+      step_smotenc(seed = TRUE)
+  )
+})
+
+# Infrastructure ---------------------------------------------------------------
+
+test_that("bake method errors when needed non-standard role columns are missing", {
+  rec <- recipe(class ~ x + y, data = circle_example) %>%
+    step_smotenc(class, skip = FALSE) %>%
+    add_role(class, new_role = "potato") %>%
+    update_role_requirements(role = "potato", bake = FALSE)
+
+  trained <- prep(rec, training = circle_example, verbose = FALSE)
+
+  expect_snapshot(
+    error = TRUE,
+    bake(trained, new_data = circle_example[, -3])
+  )
+})
+
+test_that("empty printing", {
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_smotenc(rec)
+
+  expect_snapshot(rec)
+
+  rec <- prep(rec, mtcars)
+
+  expect_snapshot(rec)
+})
+
+test_that("empty selection prep/bake is a no-op", {
+  rec1 <- recipe(mpg ~ ., mtcars)
+  rec2 <- step_smotenc(rec1)
+
+  rec1 <- prep(rec1, mtcars)
+  rec2 <- prep(rec2, mtcars)
+
+  baked1 <- bake(rec1, mtcars)
+  baked2 <- bake(rec2, mtcars)
+
+  expect_identical(baked1, baked1)
+})
+
+test_that("empty selection tidy method works", {
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_smotenc(rec)
+
+  expect <- tibble(terms = character(), id = character())
+
+  expect_identical(tidy(rec, number = 1), expect)
+
+  rec <- prep(rec, mtcars)
+
+  expect_identical(tidy(rec, number = 1), expect)
+})
+
+test_that("printing", {
+  rec <- recipe(class ~ x + y, data = circle_example) %>%
+    step_smotenc(class)
+
+  expect_snapshot(print(rec))
+  expect_snapshot(prep(rec))
+})
+
+test_that("tunable is setup to works with extract_parameter_set_dials", {
+  skip_if_not_installed("dials")
   rec <- recipe(~., data = mtcars) %>%
     step_smotenc(
       all_predictors(),
